.. _tutos:

Tutorials
=========

These tutorials are based on `Jupyter notebooks <http://jupyter.org/>`_. You can find the original notebooks
:download:`here <../examples/tuto_basic-use_py2.ipynb>` and :download:`there <../examples/tuto_bandmath_py2.ipynb>`.

.. include:: tutorials/tuto_basic-use_py2.rst

.. include:: tutorials/tuto_bandmath_py2.rst
